==> nextcloud-28.0.14.tgz: nextcloud/apps/twofactor_totp/l10n/ga.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Chuir tú ar chumas TOTP fíordheimhniú dhá-fhachtóir do do chuntas",
    "You disabled TOTP two-factor authentication for your account" : "Dhíchumasaigh tú fíordheimhniú TOTP dhá-fhachtóir do do chuntas",
    "TOTP two-factor authentication disabled by an admin" : "Díchumasaíodh fíordheimhniú dhá-fhachtóir TOTP ag riarthóir",
    "TOTP (Authenticator app)" : "TOTP (aip Authenticator)",
    "Authenticate with a TOTP app" : "Fíordheimhnigh le haip TOTP",
    "Two-Factor TOTP Provider" : "Soláthraí TOTP Dhá-Fhachtóir",
    "TOTP two-factor provider" : "TOTP soláthraí dhá-fhachtóir",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Soláthraí Dhá-Fachtóir-Údar do TOTP (RFC 6238)",
    "Enable TOTP" : "Cumasaigh TOTP",
    "Could not enable TOTP" : "Níorbh fhéidir TOTP a chumasú",
    "Could not verify your key. Please try again" : "Níorbh fhéidir d'eochair a fhíorú. Arís, le do thoil",
    "Your new TOTP secret is:" : "Is é do rún TOTP nua:",
    "For quick setup, scan this QR code with your TOTP app:" : "Chun socrú tapa a dhéanamh, scanadh an cód QR seo le do aip TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Tar éis duit do aip a chumrú, cuir isteach cód tástála thíos chun a chinntiú go n-oibríonn gach rud i gceart:",
    "Authentication code" : "Cód fíordheimhnithe",
    "Verify" : "Fíoraigh",
    "Get the authentication code from the two-factor authentication app on your device." : "Faigh an cód fíordheimhnithe ón aip fíordheimhnithe dhá-fhachtóir ar do ghléas.",
    "Submit" : "Cuir isteach"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/twofactor_totp/l10n/ga.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "Chuir tú ar chumas TOTP fíordheimhniú dhá-fhachtóir do do chuntas",
    "You disabled TOTP two-factor authentication for your account" : "Dhíchumasaigh tú fíordheimhniú TOTP dhá-fhachtóir do do chuntas",
    "TOTP two-factor authentication disabled by the administration" : "Fíordheimhniú dhá-fhachtóir TOTP díchumasaithe ag an riarachán",
    "TOTP (Authenticator app)" : "TOTP (aip Authenticator)",
    "Authenticate with a TOTP app" : "Fíordheimhnigh le haip TOTP",
    "Two-Factor TOTP Provider" : "Soláthraí TOTP Dhá-Fhachtóir",
    "Two-factor TOTP provider" : "Soláthraí TOTP dhá fhachtóir",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "Soláthraí fíordheimhnithe dhá fhachtóir le haghaidh TOTP (RFC 6238)",
    "Enable TOTP" : "Cumasaigh TOTP",
    "Could not enable TOTP" : "Níorbh fhéidir TOTP a chumasú",
    "Could not verify your key. Please try again" : "Níorbh fhéidir d'eochair a fhíorú. Arís, le do thoil",
    "Your new TOTP secret is:" : "Is é do rún TOTP nua:",
    "For quick setup, scan this QR code with your TOTP app:" : "Chun socrú tapa a dhéanamh, scanadh an cód QR seo le do aip TOTP:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "Tar éis duit do aip a chumrú, cuir isteach cód tástála thíos chun a chinntiú go n-oibríonn gach rud i gceart:",
    "Authentication code" : "Cód fíordheimhnithe",
    "Verify" : "Fíoraigh",
    "Get the authentication code from the two-factor authentication app on your device." : "Faigh an cód fíordheimhnithe ón aip fíordheimhnithe dhá-fhachtóir ar do ghléas.",
    "Submit" : "Cuir isteach",
    "TOTP two-factor authentication disabled by an admin" : "Díchumasaíodh fíordheimhniú dhá-fhachtóir TOTP ag riarthóir",
    "TOTP two-factor provider" : "TOTP soláthraí dhá-fhachtóir",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "Soláthraí Dhá-Fachtóir-Údar do TOTP (RFC 6238)"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
